pub enum AskFailure {
Decode {
codec: Symbol,
message: String,
},
Shape {
expected: String,
diagnostics: Vec<String>,
},
}Expand description
ASK failure data that can be fed back to a model as repair context.
Variants
Decode
The returned content could not be decoded by the declared codec.
Shape
The decoded value failed the declared return Shape.
Implementations