MergePolicy

Enum MergePolicy 

pub enum MergePolicy {
    Single,
    Quorum {
        min_votes: u32,
    },
    SynthesisThenVote {
        synthesizer: String,
        min_votes: u32,
    },
}
Declared policy for combining collaboration contributions.

Variants



Single

Accept one patch contribution.



Quorum

Accept one patch contribution once enough vote records target it.

Fields

min_votes: u32

Minimum number of matching vote records.



SynthesisThenVote

Accept a synthesizer patch contribution once enough vote records target it.

Fields

synthesizer: String

Seat name of the synthesizer whose patch is eligible.

min_votes: u32

Minimum number of matching vote records.