ask_packet_with_model_params

Function ask_packet_with_model_params 

pub fn ask_packet_with_model_params(
    cx: &mut Cx,
    name: &str,
    params: Vec<(String, Expr)>,
    model_params: Vec<(String, Expr)>,
    return_shape: Expr,
    to: &str,
) -> Result<BridgePacket>
Builds an ASK request packet.

Argument values are encoded through the default ASK codec at data position, wrapped in deterministic injection fences, and only then stored in the packet.