pub fn terminal_response_packet(
response: &ModelResponse,
book: &BridgeBook,
) -> Result<BridgePacket>Expand description
Decodes the terminal content item of a model response as a BRIDGE packet.
pub fn terminal_response_packet(
response: &ModelResponse,
book: &BridgeBook,
) -> Result<BridgePacket>Decodes the terminal content item of a model response as a BRIDGE packet.