validate_woven_row

Function validate_woven_row 

pub fn validate_woven_row(
    cx: &mut Cx,
    packet: &BridgePacket,
    accepted_rows: &[BridgeWeaveRow],
    row: BridgeWeaveRow,
) -> Result<BridgeReport>
Validates one candidate woven row by appending it to the accepted prefix and running the shared LOOM checker.